@@ -1,13 +1,12 @@
 from bs4 import BeautifulSoup
 
-
-from .extractors import extract_feeds
-from .extractors import extract_images
-from .extractors import extract_links
-from .extractors import extract_schemas
-from .extractors import extract_src
-from .extractors import extract_text
-from .extractors import extract_title
+from kraken_extract_from_html.extractors import extract_feeds
+from kraken_extract_from_html.extractors import extract_images
+from kraken_extract_from_html.extractors import extract_links
+from kraken_extract_from_html.extractors import extract_schemas
+from kraken_extract_from_html.extractors import extract_src
+from kraken_extract_from_html.extractors import extract_text
+from kraken_extract_from_html.extractors import extract_title
 
 
 
